@@ -18,16 +18,21 @@
 #'   gt() %>%
 #'   fmt_pad_num(columns = numbers, nsmall = 4)
 #' @section Figures:
-#' \if{html}{\figure{fmt_pad_num.png}{options: width=20\%}}
+#' \if{html}{\figure{fmt_pad_num.png}{options: width=500}}
 #'
 #' @family Utilities
 #' @section Function ID:
 #' 2-2
 
-fmt_pad_num <- function(gt_object, columns, sep = ".", nsmall = 2, pad0 = FALSE) {
+fmt_pad_num <- function(
+  gt_object,
+  columns,
+  sep = ".",
+  nsmall = 2,
+  pad0 = FALSE
+) {
   stopifnot("Table must be of class 'gt_tbl'" = "gt_tbl" %in% class(gt_object))
 
-
   gt_object %>%
     gt::fmt(
       columns = {{ columns }},
@@ -42,7 +47,6 @@ fmt_pad_num <- function(gt_object, columns, sep = ".", nsmall = 2, pad0 = FALSE)
           int_prefix <- vals[[1]]
           dec_suffix <- ifelse(length(vals) == 2, vals[[2]], "")
 
-
           html_string <- glue::glue(
             '<div><span style=" display:inline-block; text-align:right; width:{max_int}ch"> {int_prefix} </span>',
             "{sep}",
