@@ -28,27 +28,28 @@
 #'   fmt_symbol_first(hp, symbol = "&#176;", suffix = "F", symbol_first = TRUE)
 #'
 #' @section Figures:
-#' \if{html}{\figure{gt_fmt_first.png}{options: width=100\%}}
+#' \if{html}{\figure{gt_fmt_first.png}{options: width=500}}
 #'
 #' @family Utilities
 #' @section Function ID:
 #' 2-1
 
-
 fmt_symbol_first <- function(
-    gt_object,
-    column = NULL,        # column of interest to apply to
-    symbol = NULL,        # symbol to add, optionally
-    suffix = "",          # suffix to add, optionally
-    decimals = NULL,      # number of decimal places to round to
-    last_row_n = NULL,    # what's the last row in data?
-    symbol_first = FALSE, # symbol before or after suffix?,
-    scale_by = NULL,      # scaling value for things like percentages
-    gfont = NULL          # Google font option
+  gt_object,
+  column = NULL, # column of interest to apply to
+  symbol = NULL, # symbol to add, optionally
+  suffix = "", # suffix to add, optionally
+  decimals = NULL, # number of decimal places to round to
+  last_row_n = NULL, # what's the last row in data?
+  symbol_first = FALSE, # symbol before or after suffix?,
+  scale_by = NULL, # scaling value for things like percentages
+  gfont = NULL # Google font option
 ) {
   stopifnot("Table must be of class 'gt_tbl'" = "gt_tbl" %in% class(gt_object))
   # Test and error out if mandatory columns are missing
-  stopifnot("`symbol_first` argument must be a logical" = is.logical(symbol_first))
+  stopifnot(
+    "`symbol_first` argument must be a logical" = is.logical(symbol_first)
+  )
   # stopifnot("`last_row_n` argument must be specified and numeric" = is.numeric(last_row_n))
   stopifnot("Input must be a gt table" = "gt_tbl" %in% class(gt_object))
 
@@ -93,10 +94,10 @@ fmt_symbol_first <- function(
 
   # affect rows OTHER than the first row
   add_to_remainder <- function(
-    x#,
+    x #,
     # TODO remove in future?
     # length = length_nbsp
-    ) {
+  ) {
     if (!is.null(decimals) && !is.null(scale_by)) {
       # if decimal not null, convert to double
       x <- suppressWarnings(as.double(x) * scale_by)
@@ -112,8 +113,12 @@ fmt_symbol_first <- function(
     }
     paste0(
       fmt_val,
-      "<span style='color: transparent;'>", symbol, suffix,"</span>"
-      ) %>% lapply(FUN = gt::html)
+      "<span style='color: transparent;'>",
+      symbol,
+      suffix,
+      "</span>"
+    ) %>%
+      lapply(FUN = gt::html)
   }
 
   # default to nrows in input data
@@ -123,7 +128,6 @@ fmt_symbol_first <- function(
     last_row_n <- last_row_n
   }
 
-
   # pass gt object
   # align right to make sure the spacing is meaningful
   tab_out <- gt_object %>%
@@ -139,7 +143,7 @@ fmt_symbol_first <- function(
       fn = add_to_remainder
     )
 
-  if(!is.null(gfont)){
+  if (!is.null(gfont)) {
     tab_out <- tab_out %>%
       # convert to mono-font for column of interest
       tab_style(
