@@ -24,17 +24,22 @@
 #'   gt::gt() %>%
 #'   gt_alert_icon(warn)
 #' ```
-#' \if{html}{\figure{man/figures/gt_alert_icon-binary.png}{options: width=100\%}}
-gt_alert_icon <- function(gt_object,
-                          column,
-                          palette = c("#a962b6", "#f1f1f1", "#378e38"),
-                          domain = NULL,
-                          height = "10px",
-                          direction = 1,
-                          align = "center",
-                          v_pad = -5) {
+#' \if{html}{\figure{man/figures/gt_alert_icon-binary.png}{options: width=500}}
+gt_alert_icon <- function(
+  gt_object,
+  column,
+  palette = c("#a962b6", "#f1f1f1", "#378e38"),
+  domain = NULL,
+  height = "10px",
+  direction = 1,
+  align = "center",
+  v_pad = -5
+) {
   stopifnot("Table must be of class 'gt_tbl'" = "gt_tbl" %in% class(gt_object))
-  stopifnot("align must be one of 'center', 'left', or 'right'" = align %in% c("center", "left", "right"))
+  stopifnot(
+    "align must be one of 'center', 'left', or 'right'" = align %in%
+      c("center", "left", "right")
+  )
 
   if (is.null(domain)) {
     message(
@@ -52,7 +57,8 @@ gt_alert_icon <- function(gt_object,
             palette = palette,
             direction = direction,
             type = "continuous"
-          ) %>% as.character()
+          ) %>%
+            as.character()
         } else {
           if (direction == -1) {
             rev(palette)
@@ -70,7 +76,8 @@ gt_alert_icon <- function(gt_object,
             style = glue::glue("margin-top: {v_pad}px; top: 50%;")
           )
         },
-        scaled_colors, height
+        scaled_colors,
+        height
       )
     }
   ) %>%
