@@ -53,24 +53,26 @@
 #'    palette = "colorblindr::OkabeIto_black", domain = c(3,4,5))
 #' ```
 #' @section Figures:
-#' \if{html}{\figure{basic-pal.png}{options: width=100\%}}
+#' \if{html}{\figure{basic-pal.png}{options: width=500}}
 #'
-#' \if{html}{\figure{blue-pal.png}{options: width=100\%}}
+#' \if{html}{\figure{blue-pal.png}{options: width=500}}
 #'
-#' \if{html}{\figure{custom-pal.png}{options: width=100\%}}
+#' \if{html}{\figure{custom-pal.png}{options: width=500}}
 #'
-#' \if{html}{\figure{discrete-pal.png}{options: width=100\%}}
+#' \if{html}{\figure{discrete-pal.png}{options: width=500}}
 #'
 #' @family Colors
 #' @section Function ID:
 #' 4-2
-gt_color_rows <- function(gt_object,
-                          columns,
-                          palette = "ggsci::red_material",
-                          direction = 1,
-                          domain = NULL,
-                          pal_type = c("discrete", "continuous"),
-                          ...) {
+gt_color_rows <- function(
+  gt_object,
+  columns,
+  palette = "ggsci::red_material",
+  direction = 1,
+  domain = NULL,
+  pal_type = c("discrete", "continuous"),
+  ...
+) {
   stopifnot("Table must be of class 'gt_tbl'" = "gt_tbl" %in% class(gt_object))
   if (is.null(domain)) {
     warning(
@@ -88,7 +90,8 @@ gt_color_rows <- function(gt_object,
             palette = palette,
             direction = direction,
             type = pal_type
-          ) %>% as.character()
+          ) %>%
+            as.character()
         } else {
           if (direction == -1) {
             rev(palette)
