@@ -22,12 +22,17 @@
 #'   cols_width(cars ~ px(125))
 #' ```
 #' @section Figures:
-#' \if{html}{\figure{gt_dot_bar.png}{options: width=50\%}}
+#' \if{html}{\figure{gt_dot_bar.png}{options: width=500}}
 #'
 #' @family Themes
 
-gt_plt_dot <- function(gt_object, column, category_column, palette = NULL,
-                       max_value = NULL) {
+gt_plt_dot <- function(
+  gt_object,
+  column,
+  category_column,
+  palette = NULL,
+  max_value = NULL
+) {
   stopifnot("Table must be of class 'gt_tbl'" = "gt_tbl" %in% class(gt_object))
 
   # segment data with bare string column name
@@ -43,14 +48,20 @@ gt_plt_dot <- function(gt_object, column, category_column, palette = NULL,
     if (grepl(x = palette, pattern = "::", fixed = TRUE)) {
       palette <- paletteer::paletteer_d(
         palette = palette
-      ) %>% as.character()
+      ) %>%
+        as.character()
     } else {
       palette <- palette %>% rep(length(cat_levels))
     }
   } else if (is.null(palette)) {
     palette <- c(
-      "#762a83", "#af8dc3", "#e7d4e8", "#f7f7f7",
-      "#d9f0d3", "#7fbf7b", "#1b7837"
+      "#762a83",
+      "#af8dc3",
+      "#e7d4e8",
+      "#f7f7f7",
+      "#d9f0d3",
+      "#7fbf7b",
+      "#1b7837"
     )
   } else {
     palette <- palette
@@ -106,7 +117,9 @@ gt_plt_dot <- function(gt_object, column, category_column, palette = NULL,
         ),
         htmltools::div(
           style = paste0(
-            glue::glue("height: 0.7em;width: 0.7em;background-color: {colors};"),
+            glue::glue(
+              "height: 0.7em;width: 0.7em;background-color: {colors};"
+            ),
             "border-radius: 50%;margin-top:4px;display:inline-block;",
             "float:left;margin-right:2px;"
           )
@@ -118,7 +131,8 @@ gt_plt_dot <- function(gt_object, column, category_column, palette = NULL,
           )
         )
       ),
-      htmltools::div(htmltools::div(bar_chart(val_x, fill = colors)),
+      htmltools::div(
+        htmltools::div(bar_chart(val_x, fill = colors)),
         style = "position: relative;top: 1.2em;"
       )
     ) %>%
