@@ -19,7 +19,7 @@
 #'   gt_highlight_cols(cyl, fill = "red", alpha = 0.5)
 #' ```
 #' @section Figures:
-#' \if{html}{\figure{highlight-col.png}{options: width=70\%}}
+#' \if{html}{\figure{highlight-col.png}{options: width=500}}
 #'
 #' @family Utilities
 #' @section Function ID:
@@ -27,8 +27,14 @@
 #'
 #'
 
-gt_highlight_cols <- function(gt_object, columns, fill = "#80bcd8", alpha = 1,
-                              font_weight = "normal", font_color = "#000000") {
+gt_highlight_cols <- function(
+  gt_object,
+  columns,
+  fill = "#80bcd8",
+  alpha = 1,
+  font_weight = "normal",
+  font_color = "#000000"
+) {
   stopifnot("Table must be of class 'gt_tbl'" = "gt_tbl" %in% class(gt_object))
   gt_object %>%
     tab_style(
