@@ -34,26 +34,34 @@
 #'    )
 #' ```
 #' @section Figures:
-#' \if{html}{\figure{highlight-basic.png}{options: width=70\%}}
-#' \if{html}{\figure{highlight-target.png}{options: width=70\%}}
+#' \if{html}{\figure{highlight-basic.png}{options: width=500}}
+#' \if{html}{\figure{highlight-target.png}{options: width=500}}
 #'
 #' @family Utilities
 #' @section Function ID:
 #' 2-10
 
-gt_highlight_rows <- function(gt_object, columns = gt::everything(), rows = TRUE, fill = "#80bcd8",
-                              alpha = 0.8, font_weight = "bold", font_color = "#000000", bold_target_only = FALSE, target_col = c()) {
+gt_highlight_rows <- function(
+  gt_object,
+  columns = gt::everything(),
+  rows = TRUE,
+  fill = "#80bcd8",
+  alpha = 0.8,
+  font_weight = "bold",
+  font_color = "#000000",
+  bold_target_only = FALSE,
+  target_col = c()
+) {
   stopifnot("Table must be of class 'gt_tbl'" = "gt_tbl" %in% class(gt_object))
 
   if (isTRUE(bold_target_only)) {
     gt_object %>%
       tab_style(
         style = cell_fill(color = fill, alpha = alpha),
-        locations =
-          cells_body(
-            columns = {{ columns }},
-            rows = {{ rows }}
-          )
+        locations = cells_body(
+          columns = {{ columns }},
+          rows = {{ rows }}
+        )
       ) %>%
       tab_style(
         style = list(
