@@ -35,24 +35,37 @@
 #'    gt_hulk_col_numeric(mpg:disp, reverse = TRUE)
 #' ```
 #' @section Figures:
-#' \if{html}{\figure{hulk_basic.png}{options: width=100\%}}
+#' \if{html}{\figure{hulk_basic.png}{options: width=500}}
 #'
-#' \if{html}{\figure{hulk_trim.png}{options: width=100\%}}
+#' \if{html}{\figure{hulk_trim.png}{options: width=500}}
 #'
-#' \if{html}{\figure{hulk_reverse.png}{options: width=100\%}}
+#' \if{html}{\figure{hulk_reverse.png}{options: width=500}}
 #'
 #' @family Colors
 #' @section Function ID:
 #' 4-1
-gt_hulk_col_numeric <- function(gt_object, columns = NULL, domain = NULL, ..., trim = FALSE) {
+gt_hulk_col_numeric <- function(
+  gt_object,
+  columns = NULL,
+  domain = NULL,
+  ...,
+  trim = FALSE
+) {
   stopifnot("Input must be a gt table" = "gt_tbl" %in% class(gt_object))
 
   pal_hex <- c(
-    "#762a83", "#af8dc3", "#e7d4e8", "#f7f7f7",
-    "#d9f0d3", "#7fbf7b", "#1b7837"
+    "#762a83",
+    "#af8dc3",
+    "#e7d4e8",
+    "#f7f7f7",
+    "#d9f0d3",
+    "#7fbf7b",
+    "#1b7837"
   )
 
-  if (isTRUE(trim)) pal_hex <- pal_hex[2:6]
+  if (isTRUE(trim)) {
+    pal_hex <- pal_hex[2:6]
+  }
 
   hulk_pal <- function(x) {
     scales::col_numeric(
