@@ -29,13 +29,18 @@
 #'
 #' ```
 #' @section Figures:
-#' \if{html}{\figure{img-rows.png}{options: width=100\%}}
+#' \if{html}{\figure{img-rows.png}{options: width=500}}
 #'
 #' @family Utilities
 #' @section Function ID:
 #' 2-9
 
-gt_img_multi_rows <- function(gt_object, columns, img_source = "web", height = 30) {
+gt_img_multi_rows <- function(
+  gt_object,
+  columns,
+  img_source = "web",
+  height = 30
+) {
   stopifnot("Table must be of class 'gt_tbl'" = "gt_tbl" %in% class(gt_object))
   # convert tidyeval column to bare strings
   column_names <- resolve_cols_c(
@@ -43,10 +48,16 @@ gt_img_multi_rows <- function(gt_object, columns, img_source = "web", height = 3
     data = gt_object
   )
 
-  stub_var <- gt_object[["_boxhead"]][["var"]][which(gt_object[["_boxhead"]][["type"]] == "stub")]
-  grp_var <- gt_object[["_boxhead"]][["var"]][which(gt_object[["_boxhead"]][["type"]] == "row_group")]
+  stub_var <- gt_object[["_boxhead"]][["var"]][which(
+    gt_object[["_boxhead"]][["type"]] == "stub"
+  )]
+  grp_var <- gt_object[["_boxhead"]][["var"]][which(
+    gt_object[["_boxhead"]][["type"]] == "row_group"
+  )]
 
-  stopifnot("img_source must be 'web' or 'local'" = img_source %in% c("web", "local"))
+  stopifnot(
+    "img_source must be 'web' or 'local'" = img_source %in% c("web", "local")
+  )
 
   gt_object %>%
     text_transform(
