@@ -73,18 +73,32 @@ img_square <- function(value, height, width, border_color, border_weight) {
 #'   gt_img_border(img)
 #' ```
 #' @section Figures:
-#' \if{html}{\figure{gt_img_circle.png}{options: width=80\%}}
+#' \if{html}{\figure{gt_img_circle.png}{options: width=500}}
 #'
 #' @family Utilities
-gt_img_border <- function(gt_object, column, height = 25, width = 25,
-                          border_color = "black", border_weight = 2.5) {
-  stopifnot("'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in% class(gt_object))
+gt_img_border <- function(
+  gt_object,
+  column,
+  height = 25,
+  width = 25,
+  border_color = "black",
+  border_weight = 2.5
+) {
+  stopifnot(
+    "'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in%
+      class(gt_object)
+  )
 
   gt_object %>%
     text_transform(
       locations = cells_body({{ column }}),
       fn = function(value) {
-        mapply(img_square, value, height, width, border_color,
+        mapply(
+          img_square,
+          value,
+          height,
+          width,
+          border_color,
           border_weight,
           SIMPLIFY = FALSE
         )
@@ -121,20 +135,32 @@ gt_img_border <- function(gt_object, column, height = 25, width = 25,
 #'   gt_img_circle(img)
 #' ```
 #' @section Figures:
-#' \if{html}{\figure{gt_img_circle.png}{options: width=80\%}}
+#' \if{html}{\figure{gt_img_circle.png}{options: width=500}}
 #'
 #' @family Utilities
 #' @section Function ID:
 #' 2-15
-gt_img_circle <- function(gt_object, column, height = 25,
-                          border_color = "black", border_weight = 1.5) {
-  stopifnot("'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in% class(gt_object))
+gt_img_circle <- function(
+  gt_object,
+  column,
+  height = 25,
+  border_color = "black",
+  border_weight = 1.5
+) {
+  stopifnot(
+    "'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in%
+      class(gt_object)
+  )
 
   gt_object %>%
     text_transform(
       locations = cells_body({{ column }}),
       fn = function(value) {
-        mapply(img_circle, value, height, border_color,
+        mapply(
+          img_circle,
+          value,
+          height,
+          border_color,
           border_weight,
           SIMPLIFY = FALSE
         )
