@@ -24,27 +24,30 @@
 #'   gt_plt_bar(column = mpg, keep_column = TRUE)
 #' ```
 #'
-#' \if{html}{\figure{gt_plt_bar.png}{options: width=100\%}}
+#' \if{html}{\figure{gt_plt_bar.png}{options: width=500}}
 #'
 #' @family Plotting
 #' @section Function ID:
 #' 3-4
 
-gt_plt_bar <- function(gt_object,
-                       column = NULL,
-                       color = "purple",
-                       ...,
-                       keep_column = FALSE,
-                       width = 40,
-                       scale_type = "none",
-                       text_color = "white") {
+gt_plt_bar <- function(
+  gt_object,
+  column = NULL,
+  color = "purple",
+  ...,
+  keep_column = FALSE,
+  width = 40,
+  scale_type = "none",
+  text_color = "white"
+) {
   stopifnot(
     "'gt_object' must be a 'gt_tbl',
-            have you accidentally passed raw data?" = "gt_tbl" %in% class(gt_object)
+            have you accidentally passed raw data?" = "gt_tbl" %in%
+      class(gt_object)
   )
   stopifnot(
-    "`scale_type` must be one of 'number', 'percent' or 'none'" =
-      scale_type %in% c("number", "percent", "none")
+    "`scale_type` must be one of 'number', 'percent' or 'none'" = scale_type %in%
+      c("number", "percent", "none")
   )
 
   var_sym <- rlang::enquo(column)
@@ -60,8 +63,9 @@ gt_plt_bar <- function(gt_object,
   }
 
   stopifnot(
-    "Colors must be either length 1 or equal length to the column" =
-      isTRUE(length(color) == 1 | length(color) == length(all_vals))
+    "Colors must be either length 1 or equal length to the column" = isTRUE(
+      length(color) == 1 | length(color) == length(all_vals)
+    )
   )
 
   stopifnot("'text_color' must be length 1" = length(text_color) == 1)
@@ -77,7 +81,7 @@ gt_plt_bar <- function(gt_object,
     rng_multiplier <- c(0.98, 1.02)
   } else if (
     (max(all_vals, na.rm = TRUE) < 0 & min(all_vals, na.rm = TRUE) < 0)
-    ) {
+  ) {
     min_val <- min(all_vals, na.rm = TRUE)
     rng_multiplier <- c(1.02, 0)
   } else {
@@ -97,7 +101,6 @@ gt_plt_bar <- function(gt_object,
       return("<div></div>")
     }
 
-
     vals <- as.double(x_val)
 
     df_in <- dplyr::tibble(
@@ -170,7 +173,6 @@ gt_plt_bar <- function(gt_object,
     img_plot
   }
 
-
   tab_out <- text_transform(
     gt_object,
     locations = if (isTRUE(keep_column)) {
