@@ -28,23 +28,24 @@
 #'     gt_plt_dist(mpg_data)
 #' ```
 #' @section Figures:
-#' \if{html}{\figure{gt_plt_dist.png}{options: width=50\%}}
+#' \if{html}{\figure{gt_plt_dist.png}{options: width=500}}
 #'
 #' @family Plotting
 #' @section Function ID:
 #' 1-4
 
-gt_plt_dist <- function(gt_object,
-                        column,
-                        type = "density",
-                        fig_dim = c(5, 30),
-                        line_color = "black",
-                        fill_color = "grey",
-                        bw = NULL,
-                        trim = FALSE,
-                        same_limit = TRUE,
-                        type_col = NULL
-                        ) {
+gt_plt_dist <- function(
+  gt_object,
+  column,
+  type = "density",
+  fig_dim = c(5, 30),
+  line_color = "black",
+  fill_color = "grey",
+  bw = NULL,
+  trim = FALSE,
+  same_limit = TRUE,
+  type_col = NULL
+) {
   is_gt_stop(gt_object)
   # convert tidyeval column to bare string
   col_bare <- dplyr::select(gt_object[["_data"]], {{ column }}) %>% names()
@@ -55,17 +56,28 @@ gt_plt_dist <- function(gt_object,
   # convert to a single vector
   data_in <- unlist(list_data_in)
 
-  stopifnot("Specified column must contain list of values" = any(class(list_data_in) %in% "list"))
+  stopifnot(
+    "Specified column must contain list of values" = any(
+      class(list_data_in) %in% "list"
+    )
+  )
   stopifnot("Specified column must be numeric" = is.numeric(data_in))
-  stopifnot("You must indicate the `type` of plot as one of 'boxplot', 'histogram', 'rug_strip' or 'density'." = isTRUE(type %in% c("boxplot", "rug_strip", "histogram", "density")))
+  stopifnot(
+    "You must indicate the `type` of plot as one of 'boxplot', 'histogram', 'rug_strip' or 'density'." = isTRUE(
+      type %in% c("boxplot", "rug_strip", "histogram", "density")
+    )
+  )
 
   # range to be used for plotting if same axis
-  total_rng <- grDevices::extendrange(data_in, r = range(data_in, na.rm = TRUE), f = 0.02)
+  total_rng <- grDevices::extendrange(
+    data_in,
+    r = range(data_in, na.rm = TRUE),
+    f = 0.02
+  )
 
   # TODO: Need to account for bw as well.
 
   plot_fn_spark <- function(trim, list_data_in, type_in) {
-
     if (all(list_data_in %in% c(NA, NULL))) {
       return("<div></div>")
     }
@@ -160,34 +172,42 @@ gt_plt_dist <- function(gt_object,
       if (isTRUE(same_limit)) {
         if (is.null(bw)) {
           bw <- bw_calc(data_in)
-
         } else {
           bw <- bw
         }
 
         plot_out <- plot_base +
           {
-            if(bw > 0){
+            if (bw > 0) {
               geom_histogram(
-                aes(x = .data$y), 
-                color = line_color, fill = fill_color, binwidth = bw,
+                aes(x = .data$y),
+                color = line_color,
+                fill = fill_color,
+                binwidth = bw,
                 linewidth = 0.2
               )
-            } else if(bw == 0) {
+            } else if (bw == 0) {
               bw <- 1
 
               geom_histogram(
-                aes(x = .data$y), 
-                color = line_color, fill = fill_color, binwidth = bw,
+                aes(x = .data$y),
+                color = line_color,
+                fill = fill_color,
+                binwidth = bw,
                 linewidth = 0.2
               )
             } else {
-    
-              hist_breaks <- graphics::hist(data_in[!is.na(data_in)], breaks = "FD", plot=FALSE)$breaks
-    
+              hist_breaks <- graphics::hist(
+                data_in[!is.na(data_in)],
+                breaks = "FD",
+                plot = FALSE
+              )$breaks
+
               geom_histogram(
-                aes(x = .data$y), 
-                color = line_color, fill = fill_color, breaks = hist_breaks,
+                aes(x = .data$y),
+                color = line_color,
+                fill = fill_color,
+                breaks = hist_breaks,
                 linewidth = 0.2
               )
             }
@@ -247,7 +267,8 @@ gt_plt_dist <- function(gt_object,
           y = density_calc[["y"]]
         )
 
-        if (trim) { # implementation of filtering values
+        if (trim) {
+          # implementation of filtering values
           # only to actual and slightly outside the range
           filter_range <- range(vals, na.rm = TRUE) %>%
             scales::expand_range(mul = 0.05)
@@ -261,7 +282,6 @@ gt_plt_dist <- function(gt_object,
         plot_base <- ggplot(density_df) +
           theme_void()
 
-
         plot_out <- plot_base +
           geom_area(
             aes(x = .data$x, y = .data$y),
@@ -281,7 +301,10 @@ gt_plt_dist <- function(gt_object,
           bw <- bw
         }
 
-        total_rng_dens <- stats::density(stats::na.omit(as.vector(vals)), bw = bw)[["x"]]
+        total_rng_dens <- stats::density(
+          stats::na.omit(as.vector(vals)),
+          bw = bw
+        )[["x"]]
 
         density_calc <- stats::density(input_data[["y"]], bw = bw)
         density_range <- density_calc[["x"]]
@@ -291,7 +314,8 @@ gt_plt_dist <- function(gt_object,
           y = density_calc[["y"]]
         )
 
-        if (trim) { # implementation of filtering values
+        if (trim) {
+          # implementation of filtering values
           # only to actual and slightly outside the range
           filter_range <- range(vals, na.rm = TRUE) %>%
             scales::expand_range(mul = 0.05)
@@ -343,13 +367,15 @@ gt_plt_dist <- function(gt_object,
     img_plot
   }
 
-  if(!rlang::quo_is_null(rlang::enquo(type_col))){
-
+  if (!rlang::quo_is_null(rlang::enquo(type_col))) {
     type_vec <- gt_index(gt_object, {{ type_col }}, as_vector = TRUE)
     type <- type_vec
 
-    stopifnot("You must indicate the `type` of plot as one of 'boxplot', 'histogram', 'rug_strip' or 'density'." = isTRUE(all(type %in% c("boxplot", "rug_strip", "histogram", "density"))))
-
+    stopifnot(
+      "You must indicate the `type` of plot as one of 'boxplot', 'histogram', 'rug_strip' or 'density'." = isTRUE(all(
+        type %in% c("boxplot", "rug_strip", "histogram", "density")
+      ))
+    )
   }
 
   text_transform(
