@@ -27,12 +27,16 @@
 #'     )
 #'   )
 #' @section Figures:
-#' \if{html}{\figure{title-car.png}{options: width=70\%}}
+#' \if{html}{\figure{title-car.png}{options: width=500}}
 #'
 
 add_text_img <- function(text, url, height = 30, left = FALSE) {
-  text_div <- glue::glue("<div style='display:inline;vertical-align: top;'>{text}</div>")
-  img_div <- glue::glue("<div style='display:inline;margin-left:10px'>{web_image(url = url, height = height)}</div>")
+  text_div <- glue::glue(
+    "<div style='display:inline;vertical-align: top;'>{text}</div>"
+  )
+  img_div <- glue::glue(
+    "<div style='display:inline;margin-left:10px'>{web_image(url = url, height = height)}</div>"
+  )
 
   if (isFALSE(left)) {
     paste0(text_div, img_div) %>% gt::html()
