@@ -11,17 +11,17 @@
 #'   gt() %>%
 #'   gt_theme_espn()
 #' @section Figures:
-#' \if{html}{\figure{gt_espn.png}{options: width=100\%}}
+#' \if{html}{\figure{gt_espn.png}{options: width=500}}
 #'
 #' @family Themes
 #' @section Function ID:
 #' 1-2
 
-
-
-
 gt_theme_espn <- function(gt_object, ...) {
-  stopifnot("'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in% class(gt_object))
+  stopifnot(
+    "'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in%
+      class(gt_object)
+  )
 
   gt_object %>%
     opt_all_caps() %>%
