@@ -12,14 +12,17 @@
 #'   gt_theme_excel() %>%
 #'   tab_header(title = "Styled like your old pal, Excel")
 #' @section Figures:
-#' \if{html}{\figure{gt_excel.png}{options: width=75\%}}
+#' \if{html}{\figure{gt_excel.png}{options: width=500}}
 #'
 #' @family Themes
 #' @section Function ID:
 #' 1-7
 
 gt_theme_excel <- function(gt_object, ..., color = "lightgrey") {
-  stopifnot("'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in% class(gt_object))
+  stopifnot(
+    "'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in%
+      class(gt_object)
+  )
 
   gt_object %>%
     opt_row_striping() %>%
