@@ -11,14 +11,17 @@
 #'   gt() %>%
 #'   gt_theme_guardian()
 #' @section Figures:
-#' \if{html}{\figure{gt_guardian.png}{options: width=100\%}}
+#' \if{html}{\figure{gt_guardian.png}{options: width=500}}
 #'
 #' @family Themes
 #' @section Function ID:
 #' 1-4
 
 gt_theme_guardian <- function(gt_object, ...) {
-  stopifnot("'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in% class(gt_object))
+  stopifnot(
+    "'gt_object' must be a 'gt_tbl', have you accidentally passed raw data?" = "gt_tbl" %in%
+      class(gt_object)
+  )
 
   tab_out <- gt_object %>%
     opt_table_font(
@@ -29,9 +32,13 @@ gt_theme_guardian <- function(gt_object, ...) {
     ) %>%
     tab_style(
       style = cell_borders(
-        sides = "top", color = "white", weight = px(0)
+        sides = "top",
+        color = "white",
+        weight = px(0)
       ),
-      locations = cells_body(rows = ifelse(nrow(gt_object[["_data"]]) > 0, 1, NA))
+      locations = cells_body(
+        rows = ifelse(nrow(gt_object[["_data"]]) > 0, 1, NA)
+      )
     ) %>%
     tab_style(
       style = cell_text(color = "#005689", size = px(22), weight = 700),
@@ -66,7 +73,8 @@ gt_theme_guardian <- function(gt_object, ...) {
       row_group.font.weight = "bold",
       column_labels.border.top.width = px(1),
       column_labels.border.top.color = if (
-        is.null(tab_out[["_heading"]][["title"]])) {
+        is.null(tab_out[["_heading"]][["title"]])
+      ) {
         "#40c5ff"
       } else {
         "#ececec"
