@@ -24,16 +24,22 @@
 #'   )
 #' ```
 #' @section Figures:
-#' \if{html}{\figure{img_header.png}{options: width=80\%}}
+#' \if{html}{\figure{img_header.png}{options: width=500}}
 #'
 #' @family Utilities
 
-img_header <- function(label, img_url, height = 60, font_size = 12,
-                       palette = c("black", "black")) {
+img_header <- function(
+  label,
+  img_url,
+  height = 60,
+  font_size = 12,
+  palette = c("black", "black")
+) {
   html_content <- htmltools::div(
     style = "text-align: center;",
     htmltools::img(
-      src = img_url, height = gt::html(gt::px(as.integer(height))),
+      src = img_url,
+      height = gt::html(gt::px(as.integer(height))),
       style = glue::glue(
         "border-bottom: 2px solid {palette[1]};"
       )
